Index: trunk/psModules/src/camera/pmFPAfile.h
===================================================================
--- trunk/psModules/src/camera/pmFPAfile.h	(revision 14889)
+++ trunk/psModules/src/camera/pmFPAfile.h	(revision 15180)
@@ -4,6 +4,6 @@
  * @author EAM, IfA
  *
- * @version $Revision: 1.21 $ $Name: not supported by cvs2svn $
- * @date $Date: 2007-09-19 21:37:58 $
+ * @version $Revision: 1.22 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2007-10-03 21:32:43 $
  * Copyright 2004-2005 Institute for Astronomy, University of Hawaii
  */
@@ -51,6 +51,5 @@
 } pmFPAfileState;
 
-typedef struct
-{
+typedef struct {
     pmFPAfileMode mode;                 // is this file read, written, or only used internally?
     pmFPAfileType type;                 // what type of data is read from / written to disk?
@@ -63,5 +62,7 @@
 
     pmFPA *fpa;                         // for I/O files, we carry a pointer to the complete fpa
-    psFits *fits;                       // for I/O files of fits type (IMAGE, CMP, CMF), we carry a file handle
+    psFits *fits;                       // for I/O files of fits type (IMAGE, CMP, CMF) we carry a file handle
+    psFitsCompression *compression;     // Compression for FITS images
+    int bitpix;                         // Bits per pixel for output
 
     bool wrote_phu;                     // have we written a PHU for this file?
@@ -93,6 +94,5 @@
     psMetadata *format;                 // Camera format
     psString formatName;                // name of the camera format
-}
-pmFPAfile;
+} pmFPAfile;
 
 // allocate an empty pmFPAfile structure
